<template>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list-no-padding"
    v-bind="infiniteLoadingProps"
  >
    <template #renderItem="{ item, index }">
      <MessageCard
        :key="item.chatId"
        @click="goChatRoom(item)"
        :avatarUrl="item.avatarUrl ? setOSSLink(item.avatarUrl) : ''"
        :latestMessageCreationTime="item.latestMessage?.creationTime"
        :latestMessageContent="item.latestMessage?.messageContent"
        :contact="item.contact"
        :chatType="item.chatType"
        :badge="item.unReadCount ?? 0"
      ></MessageCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { useInfiniteLoading } from '@12333/hooks';
import * as messageServices from '@12333/services/api/Message';
import Taro from '@tarojs/taro';
import { setOSSLink } from '@12333/utils';

defineOptions({
  name: 'InnerPage',
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetMessageInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
      },
    };

    return messageServices.getMyUnfamiliarChatPage(params, { showLoading: false });
  },
  {
    queryKey: ['messageServices/getMyUnfamiliarChatPage'],
  }
);

function goPage(routeName: string) {
  Taro.navigateTo({
    url: routeName,
  });
}

function goChatRoom(item: API.MassgeChatOutput) {
  goPage(`${RouterPath.chatRoom}?chatId=${item.chatId}`);
}
</script>
